NAME
Pipeline::Store - defines the interface for Pipeline store classes
SYNOPSIS
use Pipeline::Store; # interface class, does very little
DESCRIPTION
Pipeline::Store provides a constructor and a generic get/set interface for any class implementing a store to sit on a Pipeline.
METHODS
The Pipeline class inherits from the Pipeline::Base class and therefore also has any additional methods that its superclass may have.
- new()
-
The
newmethod constructs a new Pipeline::Store object and calls theinitmethod. - init()
-
The
initmethod is called by new() to do any construction-time initialization of an object. - store( [ store ] )
-
The
storemethod gets or sets the store in a Pipeline::Store object. Unlessinitis changed the store is set at construction time to a hash reference. - get()
-
Does nothing in Pipeline::Store - exists as a placeholder for subclasses.
- set()
-
Does nothing in Pipeline::Store - exists as a placeholder for subclasses.
SEE ALSO
Pipeline, Pipeline::Store::Simple, Pipeline::Store::ISA
COPYRIGHT
Copyright 2003 Fotango Ltd. All Rights Reserved
This module is released under the same license as Perl itself.
AUTHOR
James A. Duncan <jduncan@fotango.com>